[diffoscope] 04/05: Hide progress bar if we are running in --debug mode as it pollutes the output.

Chris Lamb chris at chris-lamb.co.uk
Tue Mar 14 18:59:52 CET 2017


This is an automated email from the git hooks/post-receive script.

lamby pushed a commit to branch experimental
in repository diffoscope.

commit 7d9ccc69f915705842e9808df640974eca6f79bd
Author: Chris Lamb <lamby at debian.org>
Date:   Tue Mar 14 11:33:32 2017 +0100

    Hide progress bar if we are running in --debug mode as it pollutes the output.
    
    Signed-off-by: Chris Lamb <lamby at debian.org>
---
 diffoscope/progress.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/diffoscope/progress.py b/diffoscope/progress.py
index 8ec3fdc..0cfb0c1 100644
--- a/diffoscope/progress.py
+++ b/diffoscope/progress.py
@@ -45,9 +45,9 @@ class ProgressManager(object):
             if parsed_args.progress:
                 return True
 
             # ... otherwise show it if STDOUT is a tty
             if parsed_args.progress is None:
-                return sys.stdout.isatty()
+                return sys.stdout.isatty() and not parsed_args.debug
 
             return False
 
@@ -45,9 +45,9 @@ class ProgressManager(object):
                 return True
 
-            # ... otherwise show it if STDOUT is a tty
+            # ... otherwise show it if STDOUT is a tty and debug is not set
             if parsed_args.progress is None:

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/reproducible/diffoscope.git


More information about the diffoscope mailing list